@@ -91,13 +91,17 @@ from ._jsii import *
 
 __all__ = [
     "aws_lambda",
-    "common",
-    "stacks",
+    "newrelic",
+    "oidc",
+    "stack",
+    "utils",
 ]
 
 publication.publish()
 
 # Loading modules to ensure their types are registered with the jsii runtime library
 from . import aws_lambda
-from . import common
-from . import stacks
+from . import newrelic
+from . import oidc
+from . import stack
+from . import utils
